import request from '@/utils/request'
import download from '@/utils/download'

//添加会议
export function addMeeting(data){
  return request({
    url: '/meeting/add',
    method: 'post',
    data: data
  })
}

/**
 * 分页查询会议信息
 * @param data
 * @returns {*}
 */
export function getMeetingsByPage(data){
  return request({
    url: '/meeting/getMeetingsByPage',
    method: 'post',
    data:data
  })
}

/**
 * 删除会议信息
 * @param id
 * @returns {*}
 */
export function deleteMeeting(id){
  return request({
    url: '/meeting/delete?id='+id,
    method: 'get'
  })
}

/**
 * 获取会议类型为周例会列表
 * @returns {*}
 */
export function list(){
  return request({
    url: '/meeting/list',
    method: 'get'
  })
}

/**
 * 根据id获取会议明细
 * @param id
 * @returns {*}
 */
export function getMeetingDetailsById(id){
  return request({
    url: '/meeting/getMeetingDetailsById?id='+id,
    method: 'get'
  })
}

/**
 * 根据id 删除会议内容
 * @param id
 * @returns {*}
 */
export function deleteMeetingContentById(id){
  return request({
    url: '/meeting/deleteMeetingContentById?id='+id,
    method: 'get'
  })
}

/**
 * 保存会议建议
 * @param data
 * @returns {*}
 */
export function saveMeetingOptionss(data){
  return request({
    url: '/meeting/saveMeetingOptionss',
    method: 'post',
    data: data
  })
}

/**
 * 点击确认会议--生成任务报告
 * @param id
 * @returns {*}
 */
export function confirmMeetings(id){
  return request({
    url: '/meeting/confirmMeeting?id=' + id,
    method: 'get'
  })
}

/**
 * 获取待办会议列表
 * @returns {AxiosPromise}
 */
export function getTodoMeetings(){
  return request({
    url: '/meeting/getTodoMeetings',
    method: 'get'
  })
}

export function downloadPdf(){
  return download({
    url: '/meeting/download',
    method: 'get',
    responseType: 'blob',
  })
}

/**
 * 通过所属周 查询周报记录信息
 * @param meetingId
 * @param weeks
 * @returns {*}
 */
export function getWeeksRecordsByWeeks(meetingId,weeks){
  return request({
    url: '/meeting/getWeeksRecordsByWeeks?meetingId='+meetingId+'&weeks='+weeks,
    method : 'get'
  })
}

/**
 * 工作评分评论
 * @param data
 * @returns {*}
 */
export function workComments(data){
  return request({
    url: '/meeting/workComment',
    method: 'post',
    data: data
  })
}
